package com.inspect.metadata.montdata.service;

import com.inspect.metadata.montdata.domain.BasedataMontPatDevCoord;

import java.util.List;

public interface IBasedataMontPatDevCoordService {
    BasedataMontPatDevCoord selectBasedataMontPatDevCoordByMontPatDevCoordId(Long coordId);

    List<BasedataMontPatDevCoord> selectBasedataMontPatDevCoordList(BasedataMontPatDevCoord devCoord);

    int insertBasedataMontPatDevCoord(BasedataMontPatDevCoord devCoord);

    int updateBasedataMontPatDevCoord(BasedataMontPatDevCoord devCoord);

    int deleteBasedataMontPatDevCoordByMontPatDevCoordIds(Long[] coordIds);

    int deleteBasedataMontPatDevCoordByMontPatDevCoordId(Long coordId);
}
